from distutils.core import setup
setup(
  name = 'nupxrd',
  packages = ['nupxrd'], # this must be the same as the name above
  version = '0.1',
  description = 'Extract raw data from a .dat file generated on the XRD equipment',
  author = 'Ross Verploegh',
  author_email = 'ross@numat-tech.com',
  url = 'https://github.com/RossVerploegh/nupxrd', # use the URL to the github repo
  download_url = 'https://github.com/RossVerploegh/nupxrd/archive/0.1.tar.gz', # I'll explain this in a second
  keywords = ['powderXRD', 'MOF', 'NuMat'], # arbitrary keywords
  classifiers = [],
)
